Date: 08 20, 2001 4:15:03 PM

# Editing Pass Files

To edit a pass file associated with a pass in the analyzer sequence:

- In the Ana Tab, double click the pass in the analyzer sequence. The associated pass file opens up in the Workspace.

Tip: You can also open the pass file by selecting the pass in the sequence, right-clicking and selecting Edit > Pass File.

Note: For help writing rules, refer to the NLP++ section.

## See Also

Moving Passes

Inactivating Passes